@@ -7,6 +7,8 @@
 //!
 //! The buffer reader has also not implemented, but the chunks can be read by sub-parsers.
 //!
+//! # Parser
+//!
 //! Function [`parse`] is used to parse YAML string into [`Node`] data structure,
 //! which has a data holder [`Yaml`].
 //! There also has multiple thread version corresponding to [`parse_arc`], [`ArcNode`], [`ArcYaml`].
@@ -17,11 +19,27 @@
 //!
 //! If you went to rise your own error message, [`indicated_msg`] might be a good choice.
 //!
+//! # Anchors
+//!
 //! The anchor system [`AnchorBase`] is implemented by using [`alloc::rc::Rc`] and [`alloc::sync::Arc`] as inner handler.
 //! Additionally, [`anchors!`] macro can used to create anchor visitor by yourself.
+//!
+//! # Serialization and Deserialization
+//!
+//! Enable `serialize` feature to use `serde` crate.
+//! The crate provides a set of protocol traits to convert between custom Rust data.
+//! Please be aware that the additional fields will be discard when convert to a fix-sized structure.
+//! For example, the structure fields can be turned into map keys as well.
+//!
+//! On the other hand, the primitive types still able to transform to YAML data without serialization,
+//! according to `From` and `Into` traits.
+//!
+//! See [`serialize`] module for more information.
 #![no_std]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 extern crate alloc;
 extern crate core;
+
 pub use crate::anchors::*;
 pub use crate::dumper::dump;
 pub use crate::indicator::*;
@@ -126,13 +144,16 @@ macro_rules! yaml_array {
 /// ```
 #[macro_export]
 macro_rules! yaml_map {
-    () => {
-        $crate::Yaml::Map($crate::Map::new())
+    (@) => { $crate::Map::new() };
+    (@$expr:expr) => { $expr };
+    ($($k1:expr => $v1:expr $(, $k2:expr => $v2:expr)* $(,)?)?) => {
+        $crate::YamlBase::Map($crate::yaml_map!(@$({
+            let mut m = $crate::Map::new();
+            m.insert($k1, $v1);
+            $(m.insert($k2, $v2);)*
+            m
+        })?))
     };
-    ($k1:expr => $v1:expr $(, $k2:expr => $v2:expr)* $(,)?) => {{
-        use core::iter::FromIterator;
-        $crate::YamlBase::from_iter(vec![($k1, $v1) $(, ($k2, $v2))*])
-    }};
 }
 
 /// Create a custom anchor visitor.
@@ -164,6 +185,9 @@ mod indicator;
 mod node;
 pub mod parser;
 pub mod repr;
+#[cfg(feature = "serialize")]
+#[cfg_attr(docsrs, doc(cfg(feature = "serialize")))]
+pub mod serialize;
 #[cfg(test)]
 mod tests;
 mod yaml;
