@@ -1,5 +1,6 @@
 use super::*;
-use std::fmt::{Display, Formatter, Result};
+use alloc::format;
+use core::fmt::{Display, Formatter, Result};
 
 /// The error of parser handling.
 ///
@@ -31,7 +32,7 @@ impl From<()> for PError {
 }
 
 impl Display for PError {
-    fn fmt(&self, f: &mut Formatter<'_>) -> Result {
+    fn fmt(&self, f: &mut Formatter) -> Result {
         f.write_fmt(format_args!("{:?}", self))
     }
 }
