@@ -14,9 +14,9 @@ macro_rules! impl_from {
             }
         }
     };
-    ($ty1:ty $(, $ty2:ty)* => $ty:ident) => {
-        impl_from! {$ty1 => $ty}
-        $(impl_from! {$ty2 => $ty})*
+    ($($ty1:ty $(, $ty2:ty)* => $ty:ident)+) => {
+        $(impl_from! {$ty1 => $ty}
+        $(impl_from! {$ty2 => $ty})*)+
     };
 }
 
@@ -28,9 +28,9 @@ macro_rules! impl_iter {
             }
         }
     };
-    ($item1:ty $(, $item2:ty)* => $ty:ident) => {
-        impl_iter!{$item1 => $ty}
-        $(impl_iter!{$item2 => $ty})*
+    ($($item1:ty $(, $item2:ty)* => $ty:ident)+) => {
+        $(impl_iter!{$item1 => $ty}
+        $(impl_iter!{$item2 => $ty})*)+
     }
 }
 
@@ -45,7 +45,7 @@ pub type Map<R> = LinkedHashMap<NodeBase<R>, NodeBase<R>>;
 
 /// YAML data types, but it is recommended to use [`NodeBase`] for shorten code.
 ///
-/// This type can convert from primitive types by `From` and `Into` methods.
+/// This type can convert from primitive types by `From` and `Into` traits.
 ///
 /// ```
 /// use yaml_peg::Yaml;
@@ -95,14 +95,37 @@ impl<R: Repr> YamlBase<R> {
     }
 }
 
+impl<R: Repr> From<()> for YamlBase<R> {
+    fn from(_: ()) -> Self {
+        Self::Null
+    }
+}
+
 impl<R: Repr> From<bool> for YamlBase<R> {
     fn from(b: bool) -> Self {
         Self::Bool(b)
     }
 }
 
-impl_from! {&str, String, &String => Str}
-impl_from! {usize, u8, u16, u32, u64, u128, isize, i8, i16, i32, i64, i128 => Int}
-impl_from! {f32, f64 => Float}
-impl_iter! {NodeBase<R> => Array}
-impl_iter! {(NodeBase<R>, NodeBase<R>) => Map}
+impl_from! {
+    char, &str, String, &String => Str
+    usize, u8, u16, u32, u64, u128, isize, i8, i16, i32, i64, i128 => Int
+    f32, f64 => Float
+}
+
+impl<R: Repr> From<Array<R>> for YamlBase<R> {
+    fn from(a: Array<R>) -> Self {
+        Self::Array(a)
+    }
+}
+
+impl<R: Repr> From<Map<R>> for YamlBase<R> {
+    fn from(m: Map<R>) -> Self {
+        Self::Map(m)
+    }
+}
+
+impl_iter! {
+    NodeBase<R> => Array
+    (NodeBase<R>, NodeBase<R>) => Map
+}
